<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>BatchTranslationDialog</name>
    <message>
        <source>Qt Linguist - Batch Translation</source>
        <translation>Qt Linguist - 一括翻訳</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <source>Set translated entries to finished</source>
        <translation>翻訳された項目を完了にする</translation>
    </message>
    <message>
        <source>Retranslate entries with existing translation</source>
        <translation>訳語がある項目を再度翻訳する</translation>
    </message>
    <message>
        <source>Note that the modified entries will be reset to unfinished if &apos;Set translated entries to finished&apos; above is unchecked</source>
        <translation>注意:「翻訳された項目を完了にする」にチェックがついていない場合、翻訳された項目は未完了になります</translation>
    </message>
    <message>
        <source>Translate also finished entries</source>
        <translation>完了している項目も翻訳する</translation>
    </message>
    <message>
        <source>Phrase book preference</source>
        <translation>フレーズブックの設定</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation>上に移動</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation>下に移動</translation>
    </message>
    <message>
        <source>The batch translator will search through the selected phrase books in the order given above</source>
        <translation>一括翻訳機能は、上記で選択された順にフレーズブックを検索します</translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <translation>実行(&amp;R)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Batch Translation of &apos;%1&apos; - Qt Linguist</source>
        <translation>&apos;%1&apos; の一括翻訳 - Qt Linguist</translation>
    </message>
    <message>
        <source>Searching, please wait...</source>
        <translation>検索しています、お待ちください...</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>キャンセル(&amp;C)</translation>
    </message>
    <message>
        <source>Linguist batch translator</source>
        <translation>Linguist の一括翻訳</translation>
    </message>
    <message numerus="yes">
        <source>Batch translated %n entries</source>
        <translation>
            <numerusform>%n 項目が一括翻訳されました</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <source>The translation file &apos;%1&apos; will not be loaded because it is empty.</source>
        <translation>翻訳ファイル &apos;%1&apos; が空のためロードできません。</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Duplicate messages found in &apos;%1&apos;:</source>
        <translation>&lt;qt&gt;&apos;%1&apos; に重複したメッセージが見つかりました:</translation>
    </message>
    <message>
        <source>&lt;p&gt;[more duplicates omitted]</source>
        <translation>&lt;p&gt;[さらに重複している部分は省略されました]</translation>
    </message>
    <message>
        <source>&lt;p&gt;* ID: %1</source>
        <translation>&lt;p&gt; *.ID: %1</translation>
    </message>
    <message>
        <source>&lt;p&gt;* Context: %1&lt;br&gt;* Source: %2</source>
        <translation>&lt;p&gt;* コンテキスト: %1&lt;br&gt;* ソーステキスト: %2</translation>
    </message>
    <message>
        <source>&lt;br&gt;* Comment: %3</source>
        <translation>&lt;br&gt;* コメント: %3</translation>
    </message>
    <message>
        <source>Linguist does not know the plural rules for &apos;%1&apos;.
Will assume a single universal form.</source>
        <translation>Linguist は&apos;%1&apos;の複数のルールを知りません。
単一の共通形式とみなします。</translation>
    </message>
    <message>
        <source>Cannot create &apos;%2&apos;: %1</source>
        <translation>&apos;%2&apos; を作成できません: %1</translation>
    </message>
    <message>
        <source>Universal Form</source>
        <translation>共通形式</translation>
    </message>
</context>
<context>
    <name>ErrorsView</name>
    <message>
        <source>Accelerator possibly superfluous in translation.</source>
        <translation>訳に余分なアクセラレータがついています。</translation>
    </message>
    <message>
        <source>Accelerator possibly missing in translation.</source>
        <translation>訳にアクセラレータが欠けています。</translation>
    </message>
    <message>
        <source>Translation does not end with the same punctuation as the source text.</source>
        <translation>訳がソーステキストと同じ句読点で終わっていません。</translation>
    </message>
    <message>
        <source>A phrase book suggestion for &apos;%1&apos; was ignored.</source>
        <translation>&apos;%1&apos; についてのフレーズブックの示唆を無視しています。</translation>
    </message>
    <message>
        <source>Translation does not refer to the same place markers as in the source text.</source>
        <translation>訳語にはソーステキストと同じ数の &quot;%&quot; がありません。</translation>
    </message>
    <message>
        <source>Translation does not contain the necessary %n place marker.</source>
        <translation>訳語に必要なプレースマーカー &quot;%&quot; が %n 個足りません。</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知のエラー</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>このウィンドウで翻訳ソースファイル内のテキストを検索できます。</translation>
    </message>
    <message>
        <source>&amp;Find what:</source>
        <translation>検索する文字列(&amp;F):</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>検索するテキストを入力してください。</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <source>Source texts are searched when checked.</source>
        <translation>選択するとソーステキストが検索されます。</translation>
    </message>
    <message>
        <source>&amp;Source texts</source>
        <translation>ソーステキスト(&amp;S)</translation>
    </message>
    <message>
        <source>Translations are searched when checked.</source>
        <translation>選択すると訳が検索されます。</translation>
    </message>
    <message>
        <source>&amp;Translations</source>
        <translation>訳語(&amp;T)</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>選択すると、たとえば &apos;TeX&apos; と &apos;tex&apos; は異なるものと見なされます。</translation>
    </message>
    <message>
        <source>&amp;Match case</source>
        <translation>大/小文字の区別(&amp;M)</translation>
    </message>
    <message>
        <source>Comments and contexts are searched when checked.</source>
        <translation>選択するとコメントとコンテキストが検索されます。</translation>
    </message>
    <message>
        <source>&amp;Comments</source>
        <translation>コメント(&amp;C)</translation>
    </message>
    <message>
        <source>Ignore &amp;accelerators</source>
        <translation>アクセラレータを無視(&amp;A)</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>入力したテキストが次に出てくる箇所を見つけるにはここをクリックします。</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>次を検索</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>このウィンドウを閉じるにはここをクリックします。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source></source>
        <comment>Choose Edit|Find from the menu bar or press Ctrl+F to pop up the Find dialog</comment>
        <translation></translation>
    </message>
    <message>
        <source>Obsoleted messages are skipped when checked.</source>
        <translation>選択すると、廃止されたメッセージを検索対象から外します。</translation>
    </message>
    <message>
        <source>Skip &amp;obsolete</source>
        <translation>廃止された項目を無視(&amp;O)</translation>
    </message>
</context>
<context>
    <name>FormMultiWidget</name>
    <message>
        <source>Alt+Delete</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Delete</translation>
    </message>
    <message>
        <source>Shift+Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Shift+Alt+Insert</translation>
    </message>
    <message>
        <source>Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Insert</translation>
    </message>
    <message>
        <source>Confirmation - Qt Linguist</source>
        <translation>確認 - Qt Linguist</translation>
    </message>
    <message>
        <source>Delete non-empty length variant?</source>
        <translation>空ではない単数形・複数形を削除しますか?</translation>
    </message>
</context>
<context>
    <name>LRelease</name>
    <message numerus="yes">
        <source>Dropped %n message(s) which had no ID.</source>
        <translation>
            <numerusform>ID のない %n 件のメッセージを無視しました。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Excess context/disambiguation dropped from %n message(s).</source>
        <translation>
            <numerusform>不要な文脈やあいまいさ回避のコメントを %n 件のメッセージで無視しました。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Generated %n translation(s) (%1 finished and %2 unfinished)</source>
        <translation>
            <numerusform>     %n 件のメッセージを翻訳しました(完了 %1 件、未完了 %2 件)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Ignored %n untranslated source text(s)</source>
        <translation>
            <numerusform>     %n 件の未翻訳のソーステキストを無視しました</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Linguist</name>
    <message>
        <source>GNU Gettext localization files</source>
        <translation>GNU Gettext ローカライゼーションファイル</translation>
    </message>
    <message>
        <source>GNU Gettext localization template files</source>
        <translation>GNU Gettext ローカライゼーションテンプレートファイル</translation>
    </message>
    <message>
        <source>Compiled Qt translations</source>
        <translation>コンパイル済み Qt 翻訳ファイル</translation>
    </message>
    <message>
        <source>Qt Linguist &apos;Phrase Book&apos;</source>
        <translation>Qt Linguist &apos;フレーズ ブック&apos;</translation>
    </message>
    <message>
        <source>Qt translation sources</source>
        <translation>Qt 翻訳ソース</translation>
    </message>
    <message>
        <source>XLIFF localization files</source>
        <translation>XLIFF ローカライゼーションファイル</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <source>&amp;Phrases</source>
        <translation>フレーズ(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Close Phrase Book</source>
        <translation>フレーズブックを閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Edit Phrase Book</source>
        <translation>フレーズブックを編集(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Print Phrase Book</source>
        <translation>フレーズブックを印刷(&amp;P)</translation>
    </message>
    <message>
        <source>V&amp;alidation</source>
        <translation>検証(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <source>Vie&amp;ws</source>
        <translation>表示(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation>ツールバー(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Translation</source>
        <translation>翻訳(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <source>Recently Opened &amp;Files</source>
        <translation>最近使ったファイル(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>開く(&amp;O)...</translation>
    </message>
    <message>
        <source>Open a Qt translation source file (TS file) for editing</source>
        <translation>Qt 翻訳ソースファイル (TS ファイル) を編集用に開きます</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>終了(&amp;X)</translation>
    </message>
    <message>
        <source>Close this window and exit.</source>
        <translation>このウィンドウを閉じて終了します。</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file</source>
        <translation>この Qt 翻訳ソースファイルに対して行われた変更を保存します</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>名前を付けて保存(&amp;A)...</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>名前を付けて保存...</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file into a new file.</source>
        <translation>Qt の翻訳ソースファイルで行われた変更を新しいファイルに保存します。</translation>
    </message>
    <message>
        <source>Release</source>
        <translation>リリース</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file.</source>
        <translation>リリースされたアプリケーションに合う Qt メッセージファイルを、現在のメッセージファイルから作成します。</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>印刷(&amp;P)...</translation>
    </message>
    <message>
        <source>Print a list of all the translation units in the current translation source file.</source>
        <translation>現在の Qt 翻訳ソースファイルの全ての訳語の一覧を印刷します。</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>元に戻す(&amp;U)</translation>
    </message>
    <message>
        <source>Undo the last editing operation performed on the current translation.</source>
        <translation>現在の翻訳ファイルで最後に行った編集操作を取り消します。</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>やり直す(&amp;R)</translation>
    </message>
    <message>
        <source>Redo an undone editing operation performed on the translation.</source>
        <translation>取り消された編集操作をやり直します。</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>切り取り(&amp;T)</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard and deletes it.</source>
        <translation>選択された訳のテキストをクリップボードにコピーして削除します。</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>コピー(&amp;C)</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard.</source>
        <translation>選択された訳のテキストをクリップボードにコピーします。</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>貼り付け(&amp;P)</translation>
    </message>
    <message>
        <source>Paste the clipboard text into the translation.</source>
        <translation>クリップボードのテキストを訳に貼り付けます。</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>すべてを選択(&amp;A)</translation>
    </message>
    <message>
        <source>Select the whole translation text.</source>
        <translation>訳のテキスト全部を選択します。</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>検索(&amp;F)...</translation>
    </message>
    <message>
        <source>Search for some text in the translation source file.</source>
        <translation>翻訳ソースファイルからテキストを検索します。</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>次を検索(&amp;N)</translation>
    </message>
    <message>
        <source>Continue the search where it was left.</source>
        <translation>残りの部分の検索を続けます。</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Prev Unfinished</source>
        <translation>前の未訳へ(&amp;P)</translation>
    </message>
    <message>
        <source>Previous unfinished item</source>
        <translation>前の未完了の項目</translation>
    </message>
    <message>
        <source>Move to the previous unfinished item.</source>
        <translation>前の未完了の項目へ移動します。</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Next Unfinished</source>
        <translation>次の未完了へ(&amp;N)</translation>
    </message>
    <message>
        <source>Next unfinished item</source>
        <translation>次の未訳の項目</translation>
    </message>
    <message>
        <source>Move to the next unfinished item.</source>
        <translation>次の未完了の項目へ移動します。</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>P&amp;rev</source>
        <translation>前へ(&amp;R)</translation>
    </message>
    <message>
        <source>Move to previous item</source>
        <translation>前の項目へ移動</translation>
    </message>
    <message>
        <source>Move to the previous item.</source>
        <translation>前の項目へ移動します。</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Ne&amp;xt</source>
        <translation>次へ(&amp;X)</translation>
    </message>
    <message>
        <source>Next item</source>
        <translation>次の項目</translation>
    </message>
    <message>
        <source>Move to the next item.</source>
        <translation>次の項目へ移動します。</translation>
    </message>
    <message>
        <source>Ctrl+Shift+J</source>
        <translation>Ctrl+Shift+J</translation>
    </message>
    <message>
        <source>&amp;Done and Next</source>
        <translation>完了にして次へ(&amp;N)</translation>
    </message>
    <message>
        <source>Mark item as done and move to the next unfinished item</source>
        <translation>この項目に完了のマークをつけ、次の未訳の項目へ移動します</translation>
    </message>
    <message>
        <source>Mark this item as done and move to the next unfinished item.</source>
        <translation>この項目に完了のマークをつけ、次の未完了の項目へ移動します。</translation>
    </message>
    <message>
        <source>Copy from source text</source>
        <translation>ソーステキストからコピー</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field</source>
        <translation>ソーステキストを訳の欄へコピーします</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field.</source>
        <translation>ソーステキストを訳の欄へコピーします。</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>&amp;Accelerators</source>
        <translation>アクセラレータの確認(&amp;A)</translation>
    </message>
    <message>
        <source>Toggle the validity check of accelerators</source>
        <translation>アクセラレータのチェックを有効にするかどうかを切り替えます</translation>
    </message>
    <message>
        <source>Toggle the validity check of accelerators, i.e. whether the number of ampersands in the source and translation text is the same. If the check fails, a message is shown in the warnings window.</source>
        <translation>ソーステキストと訳語のアクセラレータの個数が同じか否かのチェックを有効にするかどうかを切り替えます。チェックが無効になっていても、警告ウィンドウにメッセージは表示されます。</translation>
    </message>
    <message>
        <source>&amp;Ending Punctuation</source>
        <translation>末尾の句読点(&amp;E)</translation>
    </message>
    <message>
        <source>Toggle the validity check of ending punctuation</source>
        <translation>末尾の句読点のチェックを有効にするかどうかを切り替えます</translation>
    </message>
    <message>
        <source>Toggle the validity check of ending punctuation. If the check fails, a message is shown in the warnings window.</source>
        <translation>末尾の句読点のチェックを有効にするかどうかを切り替えます。チェックが無効になっていても、警告ウィンドウにメッセージが表示されます。</translation>
    </message>
    <message>
        <source>&amp;Phrase matches</source>
        <translation>フレーズの一致(&amp;P)</translation>
    </message>
    <message>
        <source>Toggle checking that phrase suggestions are used</source>
        <translation>フレーズの示唆を使うかどうかのチェックを切り替えます</translation>
    </message>
    <message>
        <source>Toggle checking that phrase suggestions are used. If the check fails, a message is shown in the warnings window.</source>
        <translation>フレーズの示唆を使うかどうかのチェックを切り替えます。チェックが無効になっていても、警告ウィンドウにメッセージが表示されます。</translation>
    </message>
    <message>
        <source>Place &amp;Marker Matches</source>
        <translation>&quot;%&quot; の数や数字の一致(&amp;M)</translation>
    </message>
    <message>
        <source>Toggle the validity check of place markers</source>
        <translation>&quot;%&quot; の数や番号のチェックを行うかどうかを切り替えます</translation>
    </message>
    <message>
        <source>Toggle the validity check of place markers, i.e. whether %1, %2, ... are used consistently in the source text and translation text. If the check fails, a message is shown in the warnings window.</source>
        <translation>ソーステキストと訳語の&quot;%1&quot;や&quot;%2&quot;等のプレースマーカーの整合が取れているか否かのチェックを行うかどうかを切り替えます。チェックが無効になっていても、警告ウィンドウにメッセージは表示されます。</translation>
    </message>
    <message>
        <source>&amp;New Phrase Book...</source>
        <translation>新しいフレーズブック(&amp;N)...</translation>
    </message>
    <message>
        <source>Create a new phrase book.</source>
        <translation>新しいフレーズブックを作成します。</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open Phrase Book...</source>
        <translation>フレーズブックを開く(&amp;O)...</translation>
    </message>
    <message>
        <source>Open a phrase book to assist translation.</source>
        <translation>翻訳の参考にするためにフレーズブックを開きます。</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Reset Sorting</source>
        <translation>ソート順序をリセット(&amp;R)</translation>
    </message>
    <message>
        <source>Sort the items back in the same order as in the message file.</source>
        <translation>項目のソートの順序をメッセージファイルと同じものに戻します。</translation>
    </message>
    <message>
        <source>&amp;Display guesses</source>
        <translation>推測を表示(&amp;D)</translation>
    </message>
    <message>
        <source>Set whether or not to display translation guesses.</source>
        <translation>訳の推測を表示するかどうかを設定します。</translation>
    </message>
    <message>
        <source>&amp;Statistics</source>
        <translation>統計(&amp;S)</translation>
    </message>
    <message>
        <source>Display translation statistics.</source>
        <translation>翻訳の統計を表示します。</translation>
    </message>
    <message>
        <source>&amp;Manual</source>
        <translation>マニュアル(&amp;M)</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>About Qt Linguist</source>
        <translation>Qt Linguist について</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Qt について</translation>
    </message>
    <message>
        <source>Display information about the Qt toolkit by Digia.</source>
        <translation>Digia の Qt ツールキットについての情報を表示します。</translation>
    </message>
    <message>
        <source>&amp;What&apos;s This?</source>
        <translation>ヒント(&amp;W)</translation>
    </message>
    <message>
        <source>What&apos;s This?</source>
        <translation>ヒント</translation>
    </message>
    <message>
        <source>Enter What&apos;s This? mode.</source>
        <translation>ヒントモードに入ります。</translation>
    </message>
    <message>
        <source>Shift+F1</source>
        <translation>Shift+F1</translation>
    </message>
    <message>
        <source>&amp;Search And Translate...</source>
        <translation>検索して訳語を置換(&amp;S)...</translation>
    </message>
    <message>
        <source>Replace the translation on all entries that matches the search source text.</source>
        <translation>検索対象のソーステキストに該当する全項目の訳語を置換します。</translation>
    </message>
    <message>
        <source>&amp;Batch Translation...</source>
        <translation>一括翻訳(&amp;B)...</translation>
    </message>
    <message>
        <source>Batch translate all entries using the information in the phrase books.</source>
        <translation>フレーズブックにある情報を用いて、全項目を一括翻訳します。</translation>
    </message>
    <message>
        <source>Release As...</source>
        <translation>名前を付けてリリース...</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file. The filename will automatically be determined from the name of the TS file.</source>
        <translation>リリースされたアプリケーションにふさわしい Qt メッセージファイルを現在のメッセージファイルから作成します。ファイル名は、TS ファイルの名前から自動的に決められます。</translation>
    </message>
    <message>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <source>Validation</source>
        <translation>検証</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>Open/Refresh Form &amp;Preview</source>
        <translation>フォームプレビューを開く／更新する(&amp;P)</translation>
    </message>
    <message>
        <source>Form Preview Tool</source>
        <translation>フォームプレビューツール</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings...</source>
        <translation>翻訳ファイルの設定(&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Add to Phrase Book</source>
        <translation>フレーズブックに追加(&amp;A)</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Open Read-O&amp;nly...</source>
        <translation>読取専用で開く(&amp;N)...</translation>
    </message>
    <message>
        <source>&amp;Save All</source>
        <translation>全て保存(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;Release All</source>
        <translation>全てリリース(&amp;R)</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>&amp;Close All</source>
        <translation>全て閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Length Variants</source>
        <translation>文字列長バリエーション</translation>
    </message>
    <message>
        <source></source>
        <comment>This is the application&apos;s main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>ソーステキスト</translation>
    </message>
    <message>
        <source>Index</source>
        <translation>インデックス</translation>
    </message>
    <message>
        <source>Context</source>
        <translation>コンテキスト</translation>
    </message>
    <message>
        <source>Items</source>
        <translation>項目数</translation>
    </message>
    <message>
        <source>This panel lists the source contexts.</source>
        <translation>このパネルではソースのコンテキストを一覧表示しています。</translation>
    </message>
    <message>
        <source>Strings</source>
        <translation>文字列</translation>
    </message>
    <message>
        <source>Phrases and guesses</source>
        <translation>フレーズと推測</translation>
    </message>
    <message>
        <source>Sources and Forms</source>
        <translation>ソースとフォーム</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>警告</translation>
    </message>
    <message>
        <source> MOD </source>
        <comment>status bar: file(s) modified</comment>
        <translation> MOD </translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>ロードしています...</translation>
    </message>
    <message>
        <source>Loading File - Qt Linguist</source>
        <translation>ロードしています - Qt Linguist</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the currently open file(s) &apos;%2&apos;.

Close the open file(s) first?</source>
        <translation>ファイル &apos;%1&apos; は、既に開いているファイル &apos;%2&apos; とは関連していないようです。

先に開いたファイルを閉じますか?</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the file &apos;%2&apos; which is being loaded as well.

Skip loading the first named file?</source>
        <translation>ファイル &apos;%1&apos; は、既にロードされているファイル &apos;%2&apos; とは関連していないようです。

ファイルのロードをスキップしますか?</translation>
    </message>
    <message numerus="yes">
        <source>%n translation unit(s) loaded.</source>
        <translation>
            <numerusform>%n 件の翻訳項目をロードしました。</numerusform>
        </translation>
    </message>
    <message>
        <source>Related files (%1);;</source>
        <translation>%1 に関連したファイル;;</translation>
    </message>
    <message>
        <source>Open Translation Files</source>
        <translation>翻訳ファイルを開く</translation>
    </message>
    <message>
        <source>File saved.</source>
        <translation>ファイルが保存されました。</translation>
    </message>
    <message>
        <source>Qt message files for released applications (*.qm)
All files (*)</source>
        <translation>リリースされたアプリケーション用の Qt メッセージファイル (*.qm)
すべてのファイル (*)</translation>
    </message>
    <message>
        <source>File created.</source>
        <translation>ファイルが作成されました。</translation>
    </message>
    <message>
        <source>Printing...</source>
        <translation>印刷中...</translation>
    </message>
    <message>
        <source>Context: %1</source>
        <translation>コンテキスト: %1</translation>
    </message>
    <message>
        <source>finished</source>
        <translation>完了</translation>
    </message>
    <message>
        <source>unresolved</source>
        <translation>未解決</translation>
    </message>
    <message>
        <source>obsolete</source>
        <translation>このバージョンでは使われていない</translation>
    </message>
    <message>
        <source>Printing... (page %1)</source>
        <translation>印刷中... (%1 ページ)</translation>
    </message>
    <message>
        <source>Printing completed</source>
        <translation>印刷完了</translation>
    </message>
    <message>
        <source>Printing aborted</source>
        <translation>印刷中止</translation>
    </message>
    <message>
        <source>Search wrapped.</source>
        <translation>検索が一通り終わりました。</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot find the string &apos;%1&apos;.</source>
        <translation>文字列 &apos;%1&apos; が見つかりません。</translation>
    </message>
    <message>
        <source>Search And Translate in &apos;%1&apos; - Qt Linguist</source>
        <translation>&apos;%1&apos; 内で検索して翻訳 - Qt Linguist</translation>
    </message>
    <message>
        <source>Translate - Qt Linguist</source>
        <translation>翻訳 - Qt Linguist</translation>
    </message>
    <message numerus="yes">
        <source>Translated %n entry(s)</source>
        <translation>
            <numerusform>%n 項目が翻訳済みです</numerusform>
        </translation>
    </message>
    <message>
        <source>No more occurrences of &apos;%1&apos;. Start over?</source>
        <translation>&apos;%1&apos; は、これ以上見つかりません。先頭に戻りますか?</translation>
    </message>
    <message>
        <source>Create New Phrase Book</source>
        <translation>新しいフレーズブックを作成</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph)
All files (*)</source>
        <translation>Qt フレーズブック (*.qph)
全てのファイル (*)</translation>
    </message>
    <message>
        <source>Phrase book created.</source>
        <translation>フレーズブックが作成されました。</translation>
    </message>
    <message>
        <source>Open Phrase Book</source>
        <translation>フレーズブックを開く</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph);;All files (*)</source>
        <translation>Qt フレーズブック (*.qph);;すべてのファイル (*)</translation>
    </message>
    <message numerus="yes">
        <source>%n phrase(s) loaded.</source>
        <translation>
            <numerusform>%n 項目のフレーズがロードされました。</numerusform>
        </translation>
    </message>
    <message>
        <source>Add to phrase book</source>
        <translation>フレーズブックに追加</translation>
    </message>
    <message>
        <source>No appropriate phrasebook found.</source>
        <translation>適切なフレーズブックが見つかりません。</translation>
    </message>
    <message>
        <source>Adding entry to phrasebook %1</source>
        <translation>フレーズブック %1 に項目を追加</translation>
    </message>
    <message>
        <source>Select phrase book to add to</source>
        <translation>追加先のフレーズブックを選択してください</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translation>Qt Assistant (%1) を起動できません</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>バージョン %1</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).</source>
        <translation>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist は Qt アプリケーションに翻訳を追加するためのツールです。&lt;/p&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).</translation>
    </message>
    <message>
        <source>Do you want to save the modified files?</source>
        <translation>変更されたファイルを保存しますか?</translation>
    </message>
    <message>
        <source>Do you want to save &apos;%1&apos;?</source>
        <translation>&apos;%1&apos; を保存しますか?</translation>
    </message>
    <message>
        <source>Qt Linguist[*]</source>
        <translation>Qt Linguist[*]</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>No untranslated translation units left.</source>
        <translation>未訳項目は残っていません。</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>ウィンドウ(&amp;W)</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Display the manual for %1.</source>
        <translation>%1 のマニュアルを表示します。</translation>
    </message>
    <message>
        <source>Display information about %1.</source>
        <translation>%1 についての情報を表示します。</translation>
    </message>
    <message>
        <source>&amp;Save &apos;%1&apos;</source>
        <translation>&apos;%1&apos; を保存する(&amp;S)</translation>
    </message>
    <message>
        <source>Save &apos;%1&apos; &amp;As...</source>
        <translation>&apos;%1&apos; を名前を付けて保存(&amp;A)...</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos;</source>
        <translation>&apos;%1&apos; をリリース</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos; As...</source>
        <translation>&apos;%1&apos; を名前を付けてリリース...</translation>
    </message>
    <message>
        <source>&amp;Close &apos;%1&apos;</source>
        <translation>&apos;%1&apos; を閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>全て保存</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>すべて閉じる</translation>
    </message>
    <message>
        <source>&amp;Release</source>
        <translation>リリース(&amp;R)</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings for &apos;%1&apos;...</source>
        <translation>&apos;%1&apos; の翻訳ファイルの設定(&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Batch Translation of &apos;%1&apos;...</source>
        <translation>&apos;%1&apos; の一括翻訳(&amp;B)...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate in &apos;%1&apos;...</source>
        <translation>&apos;%1&apos; 内を検索して翻訳(&amp;T)...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate...</source>
        <translation>検索して訳語を置換(&amp;T)...</translation>
    </message>
    <message>
        <source>Cannot read from phrase book &apos;%1&apos;.</source>
        <translation>フレーズブック &apos;%1&apos; から読み出せません。</translation>
    </message>
    <message>
        <source>Close this phrase book.</source>
        <translation>このフレーズブックを閉じます。</translation>
    </message>
    <message>
        <source>Enables you to add, modify, or delete entries in this phrase book.</source>
        <translation>このフレーズブックで項目の追加、変更、削除ができます。</translation>
    </message>
    <message>
        <source>Print the entries in this phrase book.</source>
        <translation>このフレーズブックの項目を印刷します。</translation>
    </message>
    <message>
        <source>Cannot create phrase book &apos;%1&apos;.</source>
        <translation>フレーズブック &apos;%1&apos; を作成できません。</translation>
    </message>
    <message>
        <source>Do you want to save phrase book &apos;%1&apos;?</source>
        <translation>フレーズブック &apos;%1&apos; を保存しますか?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>すべて</translation>
    </message>
    <message>
        <source>Visualize whitespace</source>
        <translation>空白を表示</translation>
    </message>
    <message>
        <source>Toggle visualize whitespace in editors</source>
        <translation>エディタで空白を表示するかどうかを切り替えます</translation>
    </message>
</context>
<context>
    <name>MessageEditor</name>
    <message>
        <source></source>
        <comment>This is the right panel of the main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>ロシア語</translation>
    </message>
    <message>
        <source>German</source>
        <translation>ドイツ語</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>日本語</translation>
    </message>
    <message>
        <source>French</source>
        <translation>フランス語</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>ポーランド語</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>中国語</translation>
    </message>
    <message>
        <source>This whole panel allows you to view and edit the translation of some source text.</source>
        <translation>このパネル全体でソーステキストの訳を見たり編集したりすることができます。</translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>ソーステキスト</translation>
    </message>
    <message>
        <source>This area shows the source text.</source>
        <translation>この領域はソーステキストを表示します。</translation>
    </message>
    <message>
        <source>Source text (Plural)</source>
        <translation>ソーステキスト(複数)</translation>
    </message>
    <message>
        <source>This area shows the plural form of the source text.</source>
        <translation>この領域は複数のソーステキストを表示します。</translation>
    </message>
    <message>
        <source>Developer comments</source>
        <translation>開発者のコメント</translation>
    </message>
    <message>
        <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
        <translation>この領域は、手助けとなるコメントと、テキストが出てくるコンテキストを表示します。</translation>
    </message>
    <message>
        <source>Here you can enter comments for your own use. They have no effect on the translated applications.</source>
        <translation>ここはあなたが自分自身の為にコメントを入力できます。翻訳されたアプリケーションには何の影響も与えません。</translation>
    </message>
    <message>
        <source>%1 translation (%2)</source>
        <translation>%1 翻訳 (%2)</translation>
    </message>
    <message>
        <source>This is where you can enter or modify the translation of the above source text.</source>
        <translation>ソーステキストの訳を入力したり変更したりできるところです。</translation>
    </message>
    <message>
        <source>%1 translation</source>
        <translation>%1 訳</translation>
    </message>
    <message>
        <source>%1 translator comments</source>
        <translation>%1 翻訳者のコメント</translation>
    </message>
    <message>
        <source>&apos;%1&apos;
Line: %2</source>
        <translation>&apos;%1&apos;
行番号: %2</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Completion status for %1</source>
        <translation>%1 の翻訳完了状況</translation>
    </message>
    <message>
        <source>&lt;file header&gt;</source>
        <translation>&lt;ファイル ヘッダー&gt;</translation>
    </message>
    <message>
        <source>&lt;context comment&gt;</source>
        <translation>&lt;コンテキスト コメント&gt;</translation>
    </message>
    <message>
        <source>&lt;unnamed context&gt;</source>
        <translation>&lt;無名のコンテキスト&gt;</translation>
    </message>
</context>
<context>
    <name>PhraseBook</name>
    <message>
        <source>Parse error at line %1, column %2 (%3).</source>
        <translation>%1 行目、%2 列目でパースエラー (%3)。</translation>
    </message>
</context>
<context>
    <name>PhraseBookBox</name>
    <message>
        <source>Edit Phrase Book</source>
        <translation>フレーズブックを編集</translation>
    </message>
    <message>
        <source>This window allows you to add, modify, or delete entries in a phrase book.</source>
        <translation>このウィンドウでフレーズブックにフレーズを追加、変更、削除できます。</translation>
    </message>
    <message>
        <source>&amp;Translation:</source>
        <translation>訳(&amp;T):</translation>
    </message>
    <message>
        <source>This is the phrase in the target language corresponding to the source phrase.</source>
        <translation>ソースフレーズに対応する翻訳先言語のフレーズです。</translation>
    </message>
    <message>
        <source>S&amp;ource phrase:</source>
        <translation>ソースフレーズ(&amp;S):</translation>
    </message>
    <message>
        <source>This is a definition for the source phrase.</source>
        <translation>ソースフレーズの定義です。</translation>
    </message>
    <message>
        <source>This is the phrase in the source language.</source>
        <translation>ソースの言語のフレーズです。</translation>
    </message>
    <message>
        <source>&amp;Definition:</source>
        <translation>定義(&amp;D):</translation>
    </message>
    <message>
        <source>Click here to add the phrase to the phrase book.</source>
        <translation>フレーズブックにフレーズを追加するにはここをクリックしてください。</translation>
    </message>
    <message>
        <source>&amp;New Entry</source>
        <translation>新しい項目(&amp;N)</translation>
    </message>
    <message>
        <source>Click here to remove the entry from the phrase book.</source>
        <translation>フレーズブックからフレーズを消去するにはここをクリックしてください。</translation>
    </message>
    <message>
        <source>&amp;Remove Entry</source>
        <translation>項目を削除(&amp;R)</translation>
    </message>
    <message>
        <source>Settin&amp;gs...</source>
        <translation>設定(&amp;G)...</translation>
    </message>
    <message>
        <source>Click here to save the changes made.</source>
        <translation>変更を保存するにはここをクリックしてください。</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>このウィンドウを閉じるにはここをクリックします。</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source></source>
        <comment>Go to Phrase &gt; Edit Phrase Book... The dialog that pops up is a PhraseBookBox.</comment>
        <translation></translation>
    </message>
    <message>
        <source>(New Entry)</source>
        <translation>(新しい項目)</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot save phrase book &apos;%1&apos;.</source>
        <translation>フレーズブック &apos;%1&apos; を保存できません。</translation>
    </message>
</context>
<context>
    <name>PhraseModel</name>
    <message>
        <source>Source phrase</source>
        <translation>ソースフレーズ</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <source>Definition</source>
        <translation>定義</translation>
    </message>
</context>
<context>
    <name>PhraseView</name>
    <message>
        <source>Insert</source>
        <translation>挿入</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Guess (%1)</source>
        <translation>推測(%1)</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>推測</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Translation files (%1);;</source>
        <translation>翻訳ファイル (%1);;</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>すべてのファイル (*)</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>SourceCodeView</name>
    <message>
        <source>&lt;i&gt;Source code not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;ソース コードは使用できません&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;ファイル %1 が使用できません&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not readable&lt;/i&gt;</source>
        <translation>&lt;i&gt;ファイル %1 が読み込めません&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>Statistics</name>
    <message>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>ソース</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>語:</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>文字:</translation>
    </message>
    <message>
        <source>Characters (with spaces):</source>
        <translation>文字(スペースつき):</translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>このウィンドウで翻訳ソースファイル内のテキストを検索できます。</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>検索するテキストを入力してください。</translation>
    </message>
    <message>
        <source>Find &amp;source text:</source>
        <translation>ソーステキストを検索(&amp;S):</translation>
    </message>
    <message>
        <source>&amp;Translate to:</source>
        <translation>訳語(&amp;T):</translation>
    </message>
    <message>
        <source>Search options</source>
        <translation>検索オプション</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>選択すると、たとえば &apos;TeX&apos; と &apos;tex&apos; は異なるものと見なされます。</translation>
    </message>
    <message>
        <source>Match &amp;case</source>
        <translation>大文字・小文字の区別(&amp;C)</translation>
    </message>
    <message>
        <source>Mark new translation as &amp;finished</source>
        <translation>新しく翻訳した項目を完了にする(&amp;F)</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>入力したテキストが次に出てくる箇所を見つけるにはここをクリックします。</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>次を検索</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <source>Translate All</source>
        <translation>すべて翻訳</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>このウィンドウを閉じるにはここをクリックします。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>TranslationSettingsDialog</name>
    <message>
        <source>Source language</source>
        <translation>翻訳元の言語</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation>国/地域</translation>
    </message>
    <message>
        <source>Target language</source>
        <translation>翻訳先の言語</translation>
    </message>
    <message>
        <source>Settings for &apos;%1&apos; - Qt Linguist</source>
        <translation>&apos;%1&apos; の設定 - Qt Linguist</translation>
    </message>
    <message>
        <source>Any Country</source>
        <translation>指定しない</translation>
    </message>
</context>
</TS>
